==> eric-ide-19.10.tar.gz: eric-ide-19.10/eric6/E5Gui/E5ListView.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2009 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing specialized list views.
"""


from PyQt5.QtCore import Qt, QItemSelectionModel
from PyQt5.QtWidgets import QListView


class E5ListView(QListView):
    """
    Class implementing a list view supporting removal of entries.
    """
    def keyPressEvent(self, evt):
        """
        Protected method implementing special key handling.
        
        @param evt reference to the event (QKeyEvent)
        """
        if (
            evt.key() in [Qt.Key_Delete, Qt.Key_Backspace] and
            self.model() is not None
        ):
            self.removeSelected()
            evt.setAccepted(True)
        else:
            super(E5ListView, self).keyPressEvent(evt)
    
    def removeSelected(self):
        """
        Public method to remove the selected entries.
        """
        if self.model() is None or self.selectionModel() is None:
            # no models available
            return
        
        row = 0
        selectedRows = self.selectionModel().selectedRows()
        for selectedRow in reversed(selectedRows):
            row = selectedRow.row()
            self.model().removeRow(row, self.rootIndex())
        
        idx = self.model().index(row, 0, self.rootIndex())
        if not idx.isValid():
            idx = self.model().index(row - 1, 0, self.rootIndex())
        self.selectionModel().select(
            idx,
            QItemSelectionModel.SelectCurrent | QItemSelectionModel.Rows)
        self.setCurrentIndex(idx)
    
    def removeAll(self):
        """
        Public method to clear the view.
        """
        if self.model() is not None:
            self.model().removeRows(0, self.model().rowCount(self.rootIndex()),
                                    self.rootIndex())

==> eric-ide-21.4.tar.gz: eric-ide-21.4/eric6/E5Gui/E5ListView.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2009 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing specialized list views.
"""

from PyQt5.QtCore import Qt, QItemSelectionModel
from PyQt5.QtWidgets import QListView


class E5ListView(QListView):
    """
    Class implementing a list view supporting removal of entries.
    """
    def keyPressEvent(self, evt):
        """
        Protected method implementing special key handling.
        
        @param evt reference to the event (QKeyEvent)
        """
        if (
            evt.key() in [Qt.Key.Key_Delete, Qt.Key.Key_Backspace] and
            self.model() is not None
        ):
            self.removeSelected()
            evt.setAccepted(True)
        else:
            super(E5ListView, self).keyPressEvent(evt)
    
    def removeSelected(self):
        """
        Public method to remove the selected entries.
        """
        if self.model() is None or self.selectionModel() is None:
            # no models available
            return
        
        row = 0
        selectedRows = self.selectionModel().selectedRows()
        for selectedRow in reversed(selectedRows):
            row = selectedRow.row()
            self.model().removeRow(row, self.rootIndex())
        
        idx = self.model().index(row, 0, self.rootIndex())
        if not idx.isValid():
            idx = self.model().index(row - 1, 0, self.rootIndex())
        self.selectionModel().select(
            idx,
            QItemSelectionModel.SelectionFlag.SelectCurrent |
            QItemSelectionModel.SelectionFlag.Rows)
        self.setCurrentIndex(idx)
    
    def removeAll(self):
        """
        Public method to clear the view.
        """
        if self.model() is not None:
            self.model().removeRows(0, self.model().rowCount(self.rootIndex()),
                                    self.rootIndex())
